@@ -2,20 +2,21 @@
 # Copyright (c) 2020 Stephen Bunn <stephen@bunn.io>
 # ISC License <https://choosealicense.com/licenses/isc>
 
-"""Chalky.
+"""Simple ANSI terminal text coloring.
 
-Simple ANSI terminal text coloring.
 Compose multiple of the included chalk instances to produce a style that can be applied
 directly to strings.
+Compose multiple chalk instances together with ``&`` and apply it to a string
+using ``|``:
 
-Examples:
-    Compose multiple chalk instances together with ``&`` and apply it to a string
-    using ``|``:
+.. code-block:: python
+    :linenos:
 
     from chalky import sty, fg
     print(sty.bold & fg.green | "Hello, World!")
 """
 
+from .chain import chain
 from .chalk import Chalk
 from .color import Color, TrueColor
 from .shortcuts import bg, fg, hex, rgb, sty
@@ -31,4 +32,5 @@ __all__ = [
     "sty",
     "rgb",
     "hex",
+    "chain",
 ]
